#!/bin/bash
# script par Bruno
# GPLv3
# http://www.gnu.org/licenses/gpl.html

# ========================================== vérifications ===========================================

SCRIPT=$( echo $0 | sed 's/^.*\///g' )
DIR=$( echo $0 | sed 's/[^\/]*$//g')

# truecrypt est-il installé ?
if [ "$( which truecrypt )" == "" ]
then
    SYS_PROC=$( getconf LONG_BIT )
    echo "Il faut d'abord installer TrueCrypt... (pour info votre Linux tourne en ${SYS_PROC}-bit)"
    if [ "$SYS_PROC" == "64" ]
    then
        VERSION="x64"
    else
        VERSION="x86"
    fi
    echo "  1) ouvrir un terminal"
    echo "  2) taper les commandes :" 
    echo -e "     \033[36m su \033[0m"
    echo -e "     \033[36m cd \"$DIR\" \033[0m"
    echo -e "     \033[36m tar xvfz ./truecrypt-7.1a-linux-${VERSION}.tar.gz \033[0m"
    echo -e "     \033[36m ./truecrypt-7.1a-setup-${VERSION} \033[0m"
    echo ""
    echo -e "  Il est parfois nécessaire de faire \033[36m sudo su \033[0m à la place de \033[36m su \033[0m"
    echo ""
    echo "Appuyer sur <Entrée>..."
    read TOUCHE
    exit
else
    echo "Le fichier programme est bien présent : $( which truecrypt )"
    echo ""
fi

# est-on en root ?
if [ "$( whoami )" != "root" ]
then
    echo ""
    echo "Le script $SCRIPT doit être lancé en root !!!"
    echo "  1) ouvrir un terminal"
    echo "  2) taper les commandes :" 
    echo -e "     \033[36m su \033[0m"
    echo -e "     \033[36m cd \"$DIR\" \033[0m"
    echo -e "     \033[36m ./$SCRIPT \033[0m"
    echo ""
    echo -e "  Il est parfois nécessaire de faire \033[36m sudo su \033[0m à la place de \033[36m su \033[0m"
    echo ""
    echo "Appuyer sur <Entrée>..."
    read TOUCHE
    exit
fi

# se mettre dans le bon répertoire
cd "$DIR"

# vérifier que ça a fonctionné
if [ ! -d truecrypt-desktop ]
then
    echo "Erreur : le répertoire 'truecrypt-desktop' n'a pas été trouvé !"
    echo "Appuyer sur <Entrée>..."
    read TOUCHE
    exit
fi

# ============================================ variables =============================================

# enregistrer le chemin du répertoire truecrypt-desktop dans une variable
ORIGINE="$( pwd )/truecrypt-desktop"
REDEMARRER="non"

# ============================================= actions ==============================================

# ajouter le groupe s'il n'existe pas encore
if [ "$( cat /etc/group | grep truecrypt )" == "" ]
then
    echo "Ajout du groupe truecrypt."
    addgroup truecrypt
else
    echo "Le groupe truecrypt existe déjà."
fi

# renseigner l'utilisateur à autoriser
UTILISATEUR=""
while [ "$UTILISATEUR" == "" ] || [ "$( cat /etc/passwd | grep $UTILISATEUR )" == "" ]
do
    EXEMPLE=$( cat /etc/passwd | grep 1000:1000 | sed 's/:.*$//1' )
    [ "$EXEMPLE" != "" ] && EXEMPLE="(probablement ${EXEMPLE}) "
    echo -n "Utilisateur à autoriser pour TrueCrypt $EXEMPLE: "
    read UTILISATEUR
done

# ajouter l'utilisateur dans le groupe truecrypt s'il n'y est pas déjà
echo ""
if [ "$( cat /etc/group | grep truecrypt | grep $UTILISATEUR )" == "" ]
then
    adduser $UTILISATEUR truecrypt
else
    echo "L'utilisateur $UTILISATEUR est déjà dans le groupe truecrypt."
fi

# copier le fichier donnant les droits d'accès
if [ ! -f /etc/sudoers.d/truecryptuser ]
then
    cp "$ORIGINE/etc/sudoers.d/truecryptuser" /etc/sudoers.d
    chmod 440 /etc/sudoers.d/truecryptuser
    echo "Copie du fichier /etc/sudoers.d/truecryptuser effectuée."
    REDEMARRER="oui"
else
    echo "Le fichier /etc/sudoers.d/truecryptuser existe déjà."
fi

echo ""
echo "Première phase de l'installation terminée."
if [ "$REDEMARRER" != "non" ]
then
    echo "Redémarrer l'ordinateur..."
fi
echo ""
