#!/bin/bash
# script par Bruno
# GPLv3
# http://www.gnu.org/licenses/gpl.html

# ========================================== vérifications ===========================================

SCRIPT=$( echo $0 | sed 's/^.*\///g' )
REP=$( echo $0 | sed 's/[^\/]*$//g' )
if [ "$REP" == './' ]
then
	REP=$( pwd )
fi

# est-on en root ?
if [ "$( whoami )" != "root" ]
then
    echo ""
    echo "Le script $SCRIPT doit être lancé en root !!!"
    echo "  1) ouvrir un terminal"
    echo "  2) taper les commandes :" 
    echo -e "     \033[36m su \033[0m"
    echo -e "     \033[36m cd \"$REP\" \033[0m"
    echo -e "     \033[36m ./$SCRIPT \033[0m"
    echo ""
    echo -e "  Il est parfois nécessaire de faire \033[36m sudo su \033[0m à la place de \033[36m su \033[0m"
    echo ""
    echo "Appuyer sur <Entrée>..."
    read TOUCHE
    exit
fi

# se mettre dans le bon répertoire
cd "$REP"

# vérifier que ça a fonctionné
if [ ! -d truecrypt-desktop ]
then
    echo "Erreur : le répertoire 'truecrypt-desktop' n'a pas été trouvé !"
    echo "Appuyer sur <Entrée>..."
    read TOUCHE
    exit
fi

# la première étape est-elle faite ?
if [ "$( which truecrypt )" == "" ] || [ "$( cat /etc/group | grep truecrypt )" == "" ] || [ ! -f /etc/sudoers.d/truecryptuser ]
then
    echo "Renvoi vers le premier script d'installation..."
    sleep 3
    ./$( echo $SCRIPT | sed 's/2/1/' )
fi

# vérifie l'existence d'un volume favoris
FAVORITE=$( find /home -wholename "/home/*/.TrueCrypt/Favorite Volumes.xml" )
if [ "$FAVORITE" == "" ]
then
    echo "Erreur : aucun volume favori trouvé !"
    echo -e "  1) lancer TrueCrypt par le menu principal"
    echo -e "  2) créer un volume : \033[36m Create Volume \033[0m"
    echo -e "  3) le sélectionner : \033[36m Select File... \033[0m"
    echo -e "  4) le monter : \033[36m Mount \033[0m"
    echo -e "  5) l'ajouter aux favoris : menu\033[36m Favorites \033[0m>\033[36m Add Selected Volume to Favorites \033[0m"
    echo ""
    echo -n "Appuyer sur <Entrée>..."
    read TOUCHE
    exit
fi

# ============================================ variables =============================================

# cherche dans le fichier "Favorite Volumes.xml" la ligne suivant la balise <favorites>
LIGNE=$( sed -n '/<favorites>/ {n;p}' "$FAVORITE" )

# extraire le chemin du volume truecrypt
TC_FILE=$( echo $LIGNE | sed 's/^[\t ]*</</;s/<[^>]*>//g' )
echo "Le volume truecrypt favori est : $TC_FILE"

# extraire le chemin du point de montage
TC_MNT_POINT=$( echo $LIGNE | sed 's/^[\t ]*<volume mountpoint="//;s/".*$//g' )
echo "Le point de montage favori est : $TC_MNT_POINT"

# confirmation
REPONSE="n"
while [ "$REPONSE" != "o" -a "$REPONSE" != "O" ] || [ ! -f "$TC_FILE" ]
do
    echo ""
    echo -n "Ceci est-il correct [o/n] ? "
    read REPONSE
    if [ "$REPONSE" == "n" -o "$REPONSE" == "N" ]
    then
        echo ""
        echo "Entrer les bons paramètres (ou arrêter le script par Ctrl+C )"
        echo -n "Le volume truecrypt : "
        read TC_FILE
        echo -n "Le point de montage : "
        read TC_MNT_POINT
    fi
done

# chemin du répertoire truecrypt-desktop
ORIGINE="$( pwd )/truecrypt-desktop"

# variables échappées pour traitement sed
TC_FILE_SED=$( echo "$TC_FILE" | sed 's/\//\\\//g' )
TC_MNT_POINT_SED=$( echo "$TC_MNT_POINT" | sed 's/\//\\\//g' )

# ==================================== mise en place des fichiers ====================================

echo ""
echo "Copie des fichiers depuis $ORIGINE/..."
echo ""

# copier les icônes
echo ""
echo "Copie des icônes :"
for ICONE in $( ls $ORIGINE/usr/share/pixmaps )
do
    echo "---> /usr/share/pixmaps/$ICONE"
    cp -T "$ORIGINE/usr/share/pixmaps/$ICONE" "/usr/share/pixmaps/$ICONE"
    chmod 644 "/usr/share/pixmaps/$ICONE"
done

# copier les lanceurs
echo ""
echo "Copie des lanceurs :"
for LANCEUR in $( ls $ORIGINE/usr/share/applications )
do
    echo "---> /usr/share/applications/$LANCEUR"
    cp -T "$ORIGINE/usr/share/applications/$LANCEUR" "/usr/share/applications/$LANCEUR"
    chmod 644 "/usr/share/applications/$LANCEUR"
done

# copier et adapter les scripts
echo ""
echo "Copie des scripts :"
for SCRIPT in $( ls $ORIGINE/usr/local/bin )
do
    echo "---> /usr/local/bin/$SCRIPT"
    cp -T "$ORIGINE/usr/local/bin/$SCRIPT" "/usr/local/bin/$SCRIPT"
    chmod 755 "/usr/local/bin/$SCRIPT"

    # remplacer la valeur de TC_FILE (chemin du volume truecrypt) dans le script
    NUM_LIGNE=$( sed -n "/# truecrypt volume (ligne suivante à adapter)/ {n;=}" "/usr/local/bin/$SCRIPT" )
    if [ "$NUM_LIGNE" != "" ]
    then
        echo "     (chemin du volume truecrypt pris en compte)"
        sed -i "$NUM_LIGNE s/^.*$/TC_FILE=\"$TC_FILE_SED\"/" "/usr/local/bin/$SCRIPT"
    fi  

    # remplacer la valeur de TC_MNT_POINT (chemin du point de montage) dans le script
    NUM_LIGNE=$( sed -n "/# point de montage (ligne suivante à adapter)/ {n;=}" "/usr/local/bin/$SCRIPT" )
    if [ "$NUM_LIGNE" != "" ]
    then
        echo "     (chemin du point de montage pris en compte)"
        sed -i "$NUM_LIGNE s/^.*$/TC_MNT_POINT=\"$TC_MNT_POINT_SED\"/" "/usr/local/bin/$SCRIPT"
    fi  
done

echo ""
echo "Deuxième phase de l'installation terminée."
echo ""
